@@ -33,6 +33,7 @@
 #include "attributes.h"
 #include <cstdlib>
 #include <cstring>
+#include <algorithm>
 
 namespace AST {
     const std::map<expType, std::string> ASTparameter::typeNames =
@@ -207,7 +208,7 @@ namespace AST {
         }
         bool justCount = args->mType == AST::NoType;
         
-        size_t size = 0;
+        std::size_t size = 0;
         ASTparameters::const_iterator param_it = types->begin(),
                                       param_end = types->end();
         
@@ -564,7 +565,7 @@ namespace AST {
                 addUnique(syms, tr);
                 int axis = static_cast<int>(data[1]);
                 if (rectangular && (axis < 0 || axis > 1))
-                    CfdgError(where, "pm symmetry mirror axis argument must be 0 or 1");
+                    CfdgError::Error(where, "pm symmetry mirror axis argument must be 0 or 1");
                 else if (square45 && (axis < 2 || axis > 3))
                     CfdgError::Error(where, "pm symmetry mirror axis argument must be 2 or 3");
                 switch (axis) {
@@ -613,7 +614,7 @@ namespace AST {
                 addUnique(syms, tr);
                 int axis = static_cast<int>(data[1]);
                 if (rectangular && (axis < 0 || axis > 1))
-                    CfdgError(where, "pg symmetry mirror axis argument must be 0 or 1");
+                    CfdgError::Error(where, "pg symmetry mirror axis argument must be 0 or 1");
                 else if (square45 && (axis < 2 || axis > 3))
                     CfdgError::Error(where, "pg symmetry mirror axis argument must be 2 or 3");
                 switch (axis) {
@@ -662,7 +663,7 @@ namespace AST {
                 addUnique(syms, tr);
                 int axis = static_cast<int>(data[1]);
                 if (rhombic && (axis < 0 || axis > 1))
-                    CfdgError(where, "cm symmetry mirror axis argument must be 0 or 1");
+                    CfdgError::Error(where, "cm symmetry mirror axis argument must be 0 or 1");
                 else if (square && (axis < 2 || axis > 3))
                     CfdgError::Error(where, "cm symmetry mirror axis argument must be 2 or 3");
                 switch (axis) {
@@ -729,7 +730,7 @@ namespace AST {
                 agg::trans_affine tr, tr2;
                 int axis = static_cast<int>(data[1]);
                 if (rectangular && (axis < 0 || axis > 1))
-                    CfdgError(where, "pmg symmetry mirror axis argument must be 0 or 1");
+                    CfdgError::Error(where, "pmg symmetry mirror axis argument must be 0 or 1");
                 else if (square45 && (axis < 2 || axis > 3))
                     CfdgError::Error(where, "pmg symmetry mirror axis argument must be 2 or 3");
                 switch (axis) {
@@ -1039,7 +1040,7 @@ namespace AST {
                         if (sz < 1) {
                             CfdgError::Error(kid.where, "Could not evaluate this");
                         } else {
-                            size_t oldsize = symmSpec.size();
+                            std::size_t oldsize = symmSpec.size();
                             symmSpec.resize(oldsize + sz);
                             if (kid.evaluate(symmSpec.data() + oldsize, sz, r) != sz)
                                 CfdgError::Error(kid.where, "Could not evaluate this");
