@@ -35,6 +35,7 @@
 #include "builder.h"
 #include <typeinfo>
 #include <cmath>
+#include <cstddef>
 
 using std::floor;
 
@@ -99,7 +100,7 @@ namespace AST {
     {
         // Delete all of the incomplete parameters inserted during parse
         if (ph == CompilePhase::TypeCheck) {
-            for (size_t i = 0; i < mParameters.size(); ++i)
+            for (std::size_t i = 0; i < mParameters.size(); ++i)
                 if (!mParameters[i].isParameter  && !mParameters[i].isLoopIndex) {
                     mParameters.resize(i);
                     break;
@@ -429,9 +430,9 @@ namespace AST {
         if (opsOnly && !tr)
             transChild.mWorldState.m_transform.reset();
         
-        size_t modsLength = mods.size();
-        size_t totalLength = modsLength + transforms.size();
-        for(size_t i = 0; i < totalLength; ++i) {
+        std::size_t modsLength = mods.size();
+        std::size_t totalLength = modsLength + transforms.size();
+        for(std::size_t i = 0; i < totalLength; ++i) {
             Shape child(transChild);
             if (i < modsLength) {
                 mods[i]->evaluate(child.mWorldState, true, r);
@@ -441,7 +442,7 @@ namespace AST {
             r->mCurrentSeed();
 
             // Specialized mBody.traverse() with cloning behavior
-            size_t s = r->mStackSize;
+            std::size_t s = r->mStackSize;
             for (const rep_ptr& rep: mBody.mBody) {
                 if (mClone)
                     r->mCurrentSeed = cloneSeed;
@@ -487,7 +488,7 @@ namespace AST {
             return;
         if (r->mStackSize + mTuplesize > r->mCFstack.size())
             CfdgError::Error(mLocation, "Maximum stack depth exceeded");
-        size_t s = r->mStackSize;
+        std::size_t s = r->mStackSize;
         r->mStackSize += mTuplesize;
         r->mCurrentSeed ^= mChildChange.modData.mRand64Seed;
         StackType* dest = r->mCFstack.data() + s;
@@ -586,6 +587,7 @@ namespace AST {
                 r->mCurrentPath->mCommandInfo.emplace_back(r->mIndex, r->mCurrentPath.get(), width, this);
             }
             info = &(r->mCurrentPath->mCommandInfo.back());
+            info->mFlags |= child.mWorldState.m_BlendMode;
         }
 
         r->processPathCommand(child, info);
@@ -704,7 +706,7 @@ namespace AST {
                 if (mLoopArgs->isConstant) {
                     bodyNatural = finallyNatural = mLoopArgs->isNatural;
                 } else {
-                    size_t count = 0;
+                    std::size_t count = 0;
                     for (auto&& loopArg: *mLoopArgs) {
                         int num = loopArg.evaluate();
                         switch (count) {
@@ -1215,8 +1217,8 @@ namespace AST {
                 {"flags", flags.get()}
             };
         } else {
-            static const char* joinNames[5] = {"CF::MiterJoin", "???", "CF::RoundJoin", "CF::BevelJoin", "???"};
-            static const char* capNames[3] = {"CF::ButtCap", "CF::SquareCap", "CF::RoundCap"};
+            static const char* joinNames[8] = {"CF::MiterJoin", "???", "CF::RoundJoin", "CF::BevelJoin", "???"};
+            static const char* capNames[8] = {"CF::ButtCap", "CF::SquareCap", "CF::RoundCap", "???"};
             flags = joinNames[mFlags & 7];
             flags += capNames[(mFlags >> 4) & 7];
             if (mFlags & CF_ISO_WIDTH)
