@@ -42,7 +42,9 @@
 #include <limits>
 #include "scanner.h"
 #include <typeinfo>
+#include <cstddef>
 #include "backwards.h"
+#include <algorithm>
 
 using namespace AST;
 
@@ -83,7 +85,22 @@ const std::map<std::string, int> Builder::FlagNames = {
     {"CF::p3m1",        AST::CF_P3M1},
     {"CF::p31m",        AST::CF_P31M},
     {"CF::p6",          AST::CF_P6},
-    {"CF::p6m",         AST::CF_P6M}
+    {"CF::p6m",         AST::CF_P6M},
+    {"CF::Normal",      AST::CF_SRC_OVER},
+    {"CF::Clear",       AST::CF_CLEAR},
+    {"CF::Xor",         AST::CF_XOR},
+    {"CF::Plus",        AST::CF_PLUS},
+    {"CF::Multiply",    AST::CF_MULTIPLY},
+    {"CF::Screen",      AST::CF_SCREEN},
+    {"CF::Overlay",     AST::CF_OVERLAY},
+    {"CF::Darken",      AST::CF_DARKEN},
+    {"CF::Lighten",     AST::CF_LIGHTEN},
+    {"CF::ColorDodge",  AST::CF_COLOR_DODGE},
+    {"CF::ColorBurn",   AST::CF_COLOR_BURN},
+    {"CF::HardLight",   AST::CF_HARD_LIGHT},
+    {"CF::SoftLight",   AST::CF_SOFT_LIGHT},
+    {"CF::Difference",  AST::CF_DIFFERENCE},
+    {"CF::Exclusion",   AST::CF_EXCLUSION},
 };
 Builder* Builder::CurrentBuilder = nullptr;
 std::recursive_mutex Builder::BuilderMutex;
@@ -121,9 +138,12 @@ Builder::isMyBuilder() const noexcept
     return mBuilderThread == std::this_thread::get_id();
 }
 
-static const char*
-getUniqueFile(const std::string* base, const std::string* file)
+const char*
+Builder::getUniqueFile(const std::string* base, const std::string* file)
 {
+    if (!m_CFDG->system()->isGuiProgram())
+        return file->c_str();
+
     const char* b = base->c_str();
     const char* f = file->c_str();
     for (; *b && *f; ++b, ++f) {
@@ -346,7 +366,7 @@ Builder::MakeDefinition(CFG cfgnum, const yy::location& cfgLoc, exp_ptr exp)
     }
     std::string name(CFDG::ParamNames[cfgnum]);         // copy the name
     ASTdefine* cfg = new ASTdefine(name, cfgLoc);
-    cfg->mConfigDepth = static_cast<int>(mIncludeDepth);
+    cfg->mConfigDepth = mIncludeDepth;
     cfg->mDefineType = ASTdefine::ConfigDefine;
     cfg->mExpression = std::move(exp);
     return cfg;
@@ -366,7 +386,7 @@ Builder::MakeDefinition(AST::str_ptr name, const yy::location& nameLoc,
             return nullptr;
         }
         ASTdefine* cfg = new ASTdefine(*name, nameLoc);
-        cfg->mConfigDepth = static_cast<int>(mIncludeDepth);
+        cfg->mConfigDepth = mIncludeDepth;
         cfg->mDefineType = ASTdefine::ConfigDefine;
         return cfg;
     }
@@ -376,6 +396,14 @@ Builder::MakeDefinition(AST::str_ptr name, const yy::location& nameLoc,
         return nullptr;
     }
     
+    // Check if a global definition shadows a pre-definition. If it does then
+    // drop the global definition.
+    if (mContainerStack.back()->isGlobal && mIncludeDepth >= 0)
+        for (auto&& rep: mContainerStack.back()->mBody)
+            if (const ASTdefine* def = dynamic_cast<const ASTdefine*>(rep.get()))
+                if (def->mName == *name && def->mConfigDepth == -1)
+                    return nullptr;
+    
     int nameIndex = StringToShape(*name, nameLoc, false);
     if (ASTdefine* funcDef = m_CFDG->findFunction(nameIndex)) {
         error(nameLoc, "Definition with same name as user function");
@@ -482,7 +510,7 @@ Builder::MakeConfig(ASTdefine* cfg)
         
         cfg->mExpression = std::make_unique<ASTstartSpecifier>(std::move(rule), std::move(mod));
     }
-    m_CFDG->addParameter(cfgNum, std::move(cfg->mExpression), static_cast<unsigned>(cfg->mConfigDepth));
+    m_CFDG->addParameter(cfgNum, std::move(cfg->mExpression), cfg->mConfigDepth);
 }
 
 void
@@ -640,6 +668,8 @@ Builder::MakeModTerm(ASTtermArray& dest, term_ptr t)
         timeWise();
     if (t->modType == ASTmodTerm::sat || t->modType == ASTmodTerm::satTarg)
         inColor();
+    if (t->modType == ASTmodTerm::blend)
+        blended();
     
     if (lexer->startToken == yy::CfdgParser::token_type::CFDG3 &&
         t->modType >= ASTmodTerm::hueTarg && t->modType <= ASTmodTerm::targAlpha)
@@ -842,7 +872,7 @@ void
 Builder::PopNameSpace()
 {
     mCurrentNameSpace.resize(mCurrentNameSpace.length() - 2);
-    size_t end = mCurrentNameSpace.find_last_of(':');
+    std::size_t end = mCurrentNameSpace.find_last_of(':');
     if (end == std::string::npos) {
         mCurrentNameSpace.clear();
     } else {
@@ -868,7 +898,7 @@ void
 Builder::CheckName(const std::string& name, const yy::location& loc,
                    bool colonsAllowed)
 {
-    size_t pos = name.find_first_of(':');
+    std::size_t pos = name.find_first_of(':');
     if (pos == std::string::npos) return;
     if (!colonsAllowed) {
         error(loc, "namespace specification not allowed in this context");
@@ -880,7 +910,7 @@ Builder::CheckName(const std::string& name, const yy::location& loc,
     }
     for(;;) {
         if (pos == name.length() - 1 || name[pos + 1] != ':') break;
-        size_t next = name.find_first_of(':', pos + 2);
+        std::size_t next = name.find_first_of(':', pos + 2);
         if (next == std::string::npos) return;
         if (next == pos + 2) break;
         pos = next;
@@ -900,6 +930,12 @@ Builder::timeWise()
     m_CFDG->addParameter(CFDGImpl::Time);
 }
 
+void
+Builder::blended()
+{
+    m_CFDG->addParameter(CFDGImpl::Blend);
+}
+
 bool
 Builder::impure() const noexcept
 {
