@@ -40,6 +40,7 @@
 #include <cmath>
 #include <iomanip>
 #include "agg_trans_affine_time.h"
+#include <cstddef>
 
 #include "json3.hpp"
 using json = nlohmann::json;
@@ -165,9 +166,9 @@ CFDGImpl::findRule(int shapetype, double r)
     needle.mNameIndex = shapetype;
     needle.mWeight = r;
     
-    std::vector<ASTrule*>::iterator first = lower_bound(mRules.begin(), mRules.end(),
-                                                   &needle, ASTrule::compareLT);
-    if (first == mRules.end() || (*first)->mNameIndex != shapetype)
+    auto first = lower_bound(mRules.cbegin(), mRules.cend(),
+                             &needle, ASTrule::compareLT);
+    if (first == mRules.cend() || (*first)->mNameIndex != shapetype)
         throw CfdgError("Cannot find a rule for a shape (very helpful I know).");
     return *first;
 }
@@ -176,9 +177,9 @@ CFDGImpl::findRule(int shapetype, double r)
 const ASTrule*
 CFDGImpl::findRule(int shapetype)
 {
-    auto rule = std::find_if(mRules.begin(), mRules.end(),
+    auto rule = std::find_if(mRules.cbegin(), mRules.cend(),
                              [=](ASTrule* r){return r->mNameIndex == shapetype;});
-    return rule == mRules.end() ? nullptr : *rule;
+    return rule == mRules.cend() ? nullptr : *rule;
 }
 
 // Adds a new rule/path to the rule container. Updates information about the rule
@@ -205,6 +206,7 @@ CFDGImpl::addParameter(Parameter p)
     usesColor = m_Parameters & Color;
     usesTime = m_Parameters & Time;
     usesFrameTime = m_Parameters & FrameTime;
+    usesBlendMode = m_Parameters & Blend;
 }
 
 RGBA8
@@ -383,7 +385,7 @@ CFDGImpl::hasParameter(CFG name, AST::expType t, yy::location& where) const
 const ASTexpression*
 CFDGImpl::hasParameter(CFG name) const
 {
-    assert(static_cast<size_t>(name) < static_cast<size_t>(CFG::_NumberOf));
+    assert(static_cast<std::size_t>(name) < static_cast<std::size_t>(CFG::_NumberOf));
     
     if (ParamDepth[name] == NoParameter)
         return nullptr;
@@ -536,7 +538,7 @@ CFDGImpl::encodeShapeName(const std::string& s, const yy::location& where)
     int i = tryEncodeShapeName(c);
     if (i >= 0) return i;
 
-    m_shapeTypes.emplace_back(std::move(s), std::move(c), where);
+    m_shapeTypes.emplace_back(s, std::move(c), where);
     return static_cast<int>(m_shapeTypes.size()) - 1;
 }
 
