@@ -34,6 +34,7 @@
 #include <iostream>
 #include <arpa/inet.h>
 #include "prettyint.h"
+#include <unistd.h>
 
 using std::cerr;
 using std::endl;
@@ -65,7 +66,7 @@ namespace {
 
 void pngCanvas::output(const char* outfilename, int frame)
 {
-    std::unique_ptr<std::FILE, FileCloser> out(nullptr);
+    std::unique_ptr<std::FILE, FileCloser> out;
     png_structp png_ptr = nullptr;
     png_infop info_ptr = nullptr;
 
@@ -85,8 +86,15 @@ void pngCanvas::output(const char* outfilename, int frame)
         info_ptr = png_create_info_struct(png_ptr);
         if (!info_ptr) throw "couldn't create png info struct";
 
-        if (*outfilename) {
-            out.reset(std::fopen(outfilename, "wb"));
+        if (*outfilename || usetmpfile) {
+            if (usetmpfile) {
+                mFileName = "/tmp/cfdg_temp_image_XXXXXX.png";
+                int fd = mkstemps(&mFileName[0], 4);
+                if (fd != -1)
+                    out.reset(fdopen(fd, "w"));
+            } else {
+                out.reset(std::fopen(outfilename, "wb"));
+            }
         } else {
             out.reset(stdout);
 #ifdef WIN32
@@ -107,6 +115,8 @@ void pngCanvas::output(const char* outfilename, int frame)
         switch (mPixelFormat) {
             case aggCanvas::RGBA8_Blend:
             case aggCanvas::RGBA16_Blend:
+            case aggCanvas::RGBA8_Custom_Blend:
+            case aggCanvas::RGBA16_Custom_Blend:
                 pngFormat = PNG_COLOR_TYPE_RGB_ALPHA;
                 break;
             case aggCanvas::RGB8_Blend:
@@ -158,7 +168,7 @@ void pngCanvas::output(const char* outfilename, int frame)
 
         png_bytep rowPtr = mData.get() + srcy * mStride + srcx * aggCanvas::BytesPerPixel.at(mPixelFormat);
         for (int r = 0; r < height; ++r) {
-            if (mPixelFormat == aggCanvas::RGBA8_Blend) {
+            if (mPixelFormat == aggCanvas::RGBA8_Blend || mPixelFormat == aggCanvas::RGBA8_Custom_Blend) {
                 // Convert each row to non-premultiplied alpha as per PNG spec
                 // This is done in a separate array instead of in-situ because
                 // for animations the main buffer might be drawn into again
@@ -171,7 +181,7 @@ void pngCanvas::output(const char* outfilename, int frame)
                     row[c + 3] = pix.a;
                 }
                 png_write_row(png_ptr, row.get());
-            } else if (mPixelFormat == aggCanvas::RGBA16_Blend) {
+            } else if (mPixelFormat == aggCanvas::RGBA16_Blend || mPixelFormat == aggCanvas::RGBA16_Custom_Blend) {
                 // Ditto for rgba16
                 png_uint_16p rowPtr16 = reinterpret_cast<png_uint_16p>(rowPtr);
                 for (int c = 0; c < width * 4; c += 4) {
